pub struct Session {
pub ip: IpAddr,
pub ap_id: String,
pub data_plane_port: u16,
pub valid_until: DateTime<Utc>,
pub target_domains: Vec<String>,
}Expand description
Information about an authenticated IP address.
Fields
ip: IpAddrThe authenticated IP address.
ap_id: StringThe AP ID to use for sessions authenticated with this IP address.
data_plane_port: u16The port to use for data plane sessions.
valid_until: DateTime<Utc>The time until which the authentication is valid. After this time, the client needs to reauthenticate.
target_domains: Vec<String>The target domains a client is allowed to connect to.