pub struct GetDataPlaneAddressResponse {
pub address: SocketAddr,
pub snap_tun_control_address: Option<Url>,
pub snap_static_x25519: Option<PublicKey>,
}Expand description
SNAP data plane address response.
Fields
address: SocketAddrThe UDP endpoint (host:port) of the SNAP data plane.
snap_tun_control_address: Option<Url>The URL of the SNAPtun control plane API. This can be the same as the data plane address. XXX(uniquefine): Make this required once all servers have been updated.
snap_static_x25519: Option<PublicKey>The static identity of the snaptun-ng server. XXX(uniquefine): Make this required once all servers have been updated.