pub struct SnapDataPlane {
pub address: SocketAddr,
pub snap_tun_control_address: Option<Url>,
pub snap_static_x25519: Option<PublicKey>,
}Expand description
SnapDataPlane resolution response.
Fields
address: SocketAddrThe SNAP data plane address according to the rendezvous hashing that must be used by the client.
snap_tun_control_address: Option<Url>XXX(uniquefine): Make this required once all servers have been updated. The address (host:port) of the SNAPtun control plane API. This can be the same as the data plane address.
snap_static_x25519: Option<PublicKey>XXX(uniquefine): Make this required once all servers have been updated. The static identity of the snaptun-ng server.