pub struct WapSessionManager { /* private fields */ }Expand description
Manages client authentication and TCP sessions.
Implementations
Sourceimpl WapSessionManager
impl WapSessionManager
Sourcepub fn add_session_authentication(&self, auth_info: AuthInfo)
pub fn add_session_authentication(&self, auth_info: AuthInfo)
Authenticate an IP address to be able to open sessions.
The authenticated session is appended to the set of authenticated sessions for the given IP address.
Sourcepub fn authenticated_sessions_for_ip(
&self,
client_addr: IpAddr,
) -> Vec<AuthInfo>
pub fn authenticated_sessions_for_ip( &self, client_addr: IpAddr, ) -> Vec<AuthInfo>
Find the set of authenticated sessions for the given client IP address.
Sourceimpl WapSessionManager
impl WapSessionManager
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new WapSessionManager.