pub struct RefreshTokenSourceBuilder<T>where
T: TokenRefresher,{ /* private fields */ }Expand description
Builder for a RefreshTokenSource.
Implementations
Sourceimpl<T> RefreshTokenSourceBuilder<T>where
T: TokenRefresher,
impl<T> RefreshTokenSourceBuilder<T>where
T: TokenRefresher,
Sourcepub fn new(name: String, token_refresher: T) -> RefreshTokenSourceBuilder<T>
pub fn new(name: String, token_refresher: T) -> RefreshTokenSourceBuilder<T>
Creates a new builder for a RefreshTokenSource.
Arguments
name- Name of the token source, used for logging.token_refresher- Ability to refresh the token.
Sourcepub fn with_initial_token(
self,
token: TokenWithExpiry,
) -> RefreshTokenSourceBuilder<T>
pub fn with_initial_token( self, token: TokenWithExpiry, ) -> RefreshTokenSourceBuilder<T>
Seed the token source with an already-fetched token.
When set, the background task publishes this token immediately on startup
without calling TokenRefresher::refresh first. The normal refresh
loop then takes over before the token expires.
Sourcepub fn min_token_lifetime(
self,
duration: Duration,
) -> RefreshTokenSourceBuilder<T>
pub fn min_token_lifetime( self, duration: Duration, ) -> RefreshTokenSourceBuilder<T>
Minimum lifetime a token must have to be considered valid when returned by get_token.
Sourcepub fn refresh_retry_delay(
self,
duration: Duration,
) -> RefreshTokenSourceBuilder<T>
pub fn refresh_retry_delay( self, duration: Duration, ) -> RefreshTokenSourceBuilder<T>
The delay between retries if the refresh function fails.
Sourcepub fn refresh_threshold(
self,
duration: Duration,
) -> RefreshTokenSourceBuilder<T>
pub fn refresh_threshold( self, duration: Duration, ) -> RefreshTokenSourceBuilder<T>
The duration before the token’s expiry when a refresh should be attempted.
Sourcepub fn refresh_timeout(self, duration: Duration) -> RefreshTokenSourceBuilder<T>
pub fn refresh_timeout(self, duration: Duration) -> RefreshTokenSourceBuilder<T>
The duration to wait for a refresh to complete when get_token is called before a timeout.
Sourcepub fn build(self) -> RefreshTokenSource
pub fn build(self) -> RefreshTokenSource
Build the RefreshTokenSource