IdentityRegistry

Struct IdentityRegistry 

pub struct IdentityRegistry { /* private fields */ }
Registrar for SNAPtun static identities.

Implementations

Source

impl IdentityRegistry

pub fn new() -> Self

Creates a new identity registry with the given keepalive interval.

pub fn is_authorized(&self, now: Instant, identity: &[u8; 32]) -> bool

Returns true iff the identity is authorized to send packets at time now.

Eventually, this method should return the PSK under which the identity is authorized.

pub fn register<S: AsRef<str>>( &self, now: Instant, key: S, ident: [u8; 32], lifetime: Duration, ) -> bool

Registers a new identity, associated with key key and with the given lifetime. There can be at most one identity registered per key. If an identity already exists, it is overwritten. The method is indempotent.

Return value

Returns true if no registration existed before; otherwise false.

pub fn remove_expired(&self, now: Instant)

Removes all expired entries.