pub struct IdentityRegistry { /* private fields */ }Expand description
Registrar for SNAPtun static identities.
Implementations
Sourceimpl IdentityRegistry
impl IdentityRegistry
Returns true iff the identity is authorized to send packets at time
now.
Eventually, this method should return the PSK under which the identity is authorized.
Sourcepub fn register<S: AsRef<str>>(
&self,
now: Instant,
key: S,
ident: [u8; 32],
lifetime: Duration,
) -> bool
pub fn register<S: AsRef<str>>( &self, now: Instant, key: S, ident: [u8; 32], lifetime: Duration, ) -> bool
Registers a new identity, associated with key key and with the given
lifetime. There can be at most one identity registered per key. If an
identity already exists, it is overwritten. The method is indempotent.
Return value
Returns true if no registration existed before; otherwise false.
Sourcepub fn remove_expired(&self, now: Instant)
pub fn remove_expired(&self, now: Instant)
Removes all expired entries.